================
Project Overview
================

Tiote enables django websites to administer PostgreSQL and MySQL databases. It provides a clean and intuitive interface to your database(s) with which you can use Database level functions. This functions can be summarised as CRUD (Create, Read, Update and Delete). It has been tested both on linux (ubuntu), and epio (https://ep.io) environments.

Screenshots of tiote
====================

Database Overview
-----------------

.. image:: images/db_overview.*

Browsing a Table
----------------

.. image:: images/browse_table.*

Editing a Table Row
-------------------

.. image:: images/edit_table_data.*

Table Structure
---------------
.. image:: images/table_structure.*


.. Design Decisions
.. ================
